@@ -36,6 +36,10 @@ print_error (const Gnome::Vfs::exception& ex, const std::string& uri_string)
 
 int main (int argc, char** argv)
 {
+#ifndef GLIBMM_EXCEPTIONS_ENABLED
+  std::auto_ptr<Gnome::Vfs::exception> error;
+#endif
+
   // This should read the contents of one file and output them to another file.
   
   // Get the command-line arguments:
@@ -58,6 +62,7 @@ int main (int argc, char** argv)
   // open the input file for read access
   Gnome::Vfs::Handle read_handle;
   
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     read_handle.open(input_uri_string, Gnome::Vfs::OPEN_READ);
@@ -67,6 +72,15 @@ int main (int argc, char** argv)
     // If the operation was not successful, print the error and abort
     return print_error(ex, input_uri_string);
   }
+#else
+  read_handle.open(input_uri_string, Gnome::Vfs::OPEN_READ, error);
+
+  if(error.get())
+  {
+    // If the operation was not successful, print the error and abort
+    return print_error(*error.get(), input_uri_string);
+  }
+#endif //GLIBMM_EXCEPTIONS_ENABLED
   
   /* we use create instead of open, because open will not create the file if it does
      not already exist. The last argument is the permissions to use if the file is created,
@@ -74,6 +88,7 @@ int main (int argc, char** argv)
 
   Gnome::Vfs::Handle write_handle;
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     //0660 means "this user and his group can read and write this non-executable file".
@@ -85,6 +100,17 @@ int main (int argc, char** argv)
     // If the operation was not successful, print the error and abort
     return print_error(ex, output_uri_string);
   }
+#else
+  //0660 means "this user and his group can read and write this non-executable file".
+  //The 0 prefix means that this is octal.
+  write_handle.create(output_uri_string, Gnome::Vfs::OPEN_WRITE, false, 0660, error);
+
+  if(error.get())
+  {
+    // If the operation was not successful, print the error and abort
+    return print_error(*error.get(), output_uri_string);
+  }
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
 
   // Read data from the input uri:
@@ -93,12 +119,24 @@ int main (int argc, char** argv)
   // We use std::string instead of Glib::ustring because it might not be UTF8-encoded. 
 
   Gnome::Vfs::FileSize bytes_read = 0;
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
+#endif //GLIBMM_EXCEPTIONS_ENABLED
     bool bContinue = true;
     while(bContinue)
     {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
       bytes_read = read_handle.read(buffer, BYTES_TO_PROCESS);
+#else
+      bytes_read = read_handle.read(buffer, BYTES_TO_PROCESS, error);
+
+      if(error.get())
+      {
+        // If the operation was not successful, print the error and abort
+        return print_error(*error.get(), input_uri_string);
+      }
+#endif //GLIBMM_EXCEPTIONS_ENABLED
     
       if(bytes_read == 0)
         bContinue = false; //stop because we reached the end.
@@ -108,12 +146,14 @@ int main (int argc, char** argv)
         text_whole += std::string((char*)buffer, bytes_read);
       }
     }
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   }
   catch(const Gnome::Vfs::exception& ex)
   {
     // If the operation was not successful, print the error and abort
     return print_error(ex, input_uri_string);
   }
+#endif //GLIBMM_EXCEPTIONS_ENABLED
   
   //Now we have the contents of the file in text_whole.
   //We are assuming that it is a text file.
@@ -124,6 +164,7 @@ int main (int argc, char** argv)
 
   // Seek to the end of the output uri so we will append rather than overwrite.
   // Therefore, we seek 0 bytes relative to the end of the file
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
     write_handle.seek(Gnome::Vfs::SEEK_POS_END, 0);
@@ -136,6 +177,24 @@ int main (int argc, char** argv)
     // If the operation was not successful, print the error and abort
     return print_error(ex, output_uri_string);
   }
+#else
+  write_handle.seek(Gnome::Vfs::SEEK_POS_END, 0, error);
+
+  if(error.get())
+  {
+    // If the operation was not successful, print the error and abort
+    return print_error(*error.get(), output_uri_string);
+  }
+
+  // Now write the data we read out to the output uri
+  GnomeVFSFileSize bytes_written = write_handle.write(text_whole.data(), text_whole.size(), error);
+
+  if(error.get())
+  {
+    // If the operation was not successful, print the error and abort
+    return print_error(*error.get(), output_uri_string);
+  }
+#endif //GLIBMM_EXCEPTIONS_ENABLED
   
   return 0;
 }
